export default class FileToUpload {
    static chunkSize = 262144;
    readonly request: XMLHttpRequest;
    static uploadUrl = 'https://api.portalmec.c3sl.ufpr.br/v1/learning_objects/1231';
    readonly file: File;
    readonly name: string;
    readonly draftID: string;
    readonly _chunkIdentifier: string;
    private _chunkNumber: number;
    currentChunkStartByte: number;
    currentChunkFinalByte: number;

    constructor(file: File, name: string, draftID : string) {
        this.request = new XMLHttpRequest();
        this.request.overrideMimeType('application/octet-stream');

        this.file = file;
        this.name = name;
        this.draftID = draftID;
        this._chunkIdentifier = draftID + '-'  + this.name;
        this._chunkNumber = 0;

        this.currentChunkStartByte = 0;
        this.currentChunkFinalByte = FileToUpload.chunkSize > this.file.size ? this.file.size : FileToUpload.chunkSize;
    }

    uploadFile() {
        this.request.open('POST', FileToUpload.uploadUrl, true);

        let chunk: Blob = this.file.slice(this.currentChunkStartByte, this.currentChunkFinalByte);  // split the file according to the boundaries
        this.request.setRequestHeader('Content-Range', `bytes ${this.currentChunkStartByte}-${this.currentChunkFinalByte}/${this.file.size}`);

        //this.request.setRequestHeader('uid', sessionStorage.getItem('@portalmec/uid'))
        //this.request.setRequestHeader('client', sessionStorage.getItem('@portalmec/clientToken'))

        this.request.onload = () => {
            const remainingBytes = this.file.size - this.currentChunkFinalByte;

            if(this.currentChunkFinalByte === this.file.size) {
                alert('Yay, upload completed! Chao!');
                return;
            } else if (remainingBytes < FileToUpload.chunkSize) {
                // if the remaining chunk is smaller than the chunk size we defined
                this.currentChunkStartByte = this.currentChunkFinalByte;
                this.currentChunkFinalByte = this.currentChunkStartByte + remainingBytes;
            }
            else {
                // keep chunking
                this.currentChunkStartByte = this.currentChunkFinalByte;
                this.currentChunkFinalByte = this.currentChunkStartByte + FileToUpload.chunkSize;
            }

            this.uploadFile();
            this._chunkNumber = this._chunkNumber + 1
        }

        const formData = new FormData();
        formData.append('_chunkFilename', this.file.name);
        formData.append('_chunkIdentifier', this._chunkIdentifier);
        formData.append('_totalChunks', String(Math.ceil(this.file.size/FileToUpload.chunkSize)));
        formData.append('_chunkSize', String(FileToUpload.chunkSize));
        formData.append('_currentChunkSize', String(this.currentChunkFinalByte - this.currentChunkStartByte));
        formData.append('_chunkNumber', String(this._chunkNumber));
        formData.append('_totalSize', String(this.file.size));
        formData.append('file', chunk);

        this.request.send(formData);// send it now!
    }
}
