/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState} from 'react'
import LinkIcon from '../../img/link_icon.svg'
import ChooseLink from './ChooseLinkSection.js'
import {WrapperBox, StyledTextField, BlueButton, GrayButton} from './StyledComponents.js';
import UploadMediaComponent from './DragAndDrop.tsx'
import FileUploadStage from './FileUploadStage.js'

export default function UploadFileWrapper (props) {
    /*-----------------------------------------------------------------
        - Wrapper for file upload box
        - has three different stages:
            - Default, contained within this function's default return
            - Choosing Link: displayed when the user selects "ENVIAR LINK"; renders "ChooseLinkSection.js"
            - Uploading File: displayed when the user chooses a file to upload. The file upload box is in "DragAndDrop.js", and the actual upload view is in "FileUploadStage.js"

        - Props used:
            - submit : called when the user clicks "ENVIAR" inside ChooseLinkSection; renders the alert snackbar to let them know the link was submitted
    */

    const [stage, setStage] = useState("default")
    const handleNextStage = (newStage) => {setStage(newStage)}

    const [files, setFile] = useState([])

    const acceptFile = (files) => {
        console.log(files)
        setFile(files)
        setStage("fileSelected")
    }

    switch (stage) {
        case "fileSelected":
            return(
                <FileUploadStage files={files}/>
            )
        case "choosingLink":
            return (
                <ChooseLink handleNextStage={handleNextStage} submit={props.submit}/>
            )
            break;
        default:
            return(
                <WrapperBox>
                    <div className="inner">
                        <div className="upload-title"> Enviar Recurso</div>
                        <div className="flex-column">
                            {/*props.draftID*/}
                            <UploadMediaComponent draftID={'123123'}/>
                            <div className="strike-box">
                                <div className="strike"/><h3>ou</h3><div className="strike"/>
                            </div>

                            <div className="enviar-link-texto">
                                <img src={LinkIcon}/>
                                <br/>
                                <span>Enviar link de um recurso de outro site</span>
                            </div>

                            <BlueButton onClick={ () => {handleNextStage("choosingLink")} }>ENVIAR LINK</BlueButton>
                        </div>
                    </div>
                </WrapperBox>
            )
    }

}
